@@ -4,8 +4,9 @@
 // So, we switch here, using `enum class` for enums with no associated data
 // and `sealed class` for the general case.
 #}
-
-{% if e.is_flat() %}
+{% import "macros.kt" as kt %}
+{%- let e = self.inner() %}
+{%- if e.is_flat() %}
 
 enum class {{ e.name()|class_name_kt }} {
     {% for variant in e.variants() -%}
@@ -35,8 +36,7 @@ enum class {{ e.name()|class_name_kt }} {
 
 {% else %}
 
-{% call kt::unsigned_types_annotation(e) %}
-sealed class {{ e.name()|class_name_kt }}{% if ci.item_contains_object_references(e) %}: Disposable {% endif %} {
+sealed class {{ e.name()|class_name_kt }}{% if self.contains_object_references() %}: Disposable {% endif %} {
     {% for variant in e.variants() -%}
     {% if !variant.has_fields() -%}
     object {{ variant.name()|class_name_kt }} : {{ e.name()|class_name_kt }}()
@@ -85,17 +85,17 @@ sealed class {{ e.name()|class_name_kt }}{% if ci.item_contains_object_reference
         }.let { /* this makes the `when` an expression, which ensures it is exhaustive */ }
     }
 
-    {% if ci.item_contains_object_references(e) %}
+    {% if self.contains_object_references() %}
     @Suppress("UNNECESSARY_SAFE_CALL") // codegen is much simpler if we unconditionally emit safe calls here
     override fun destroy() {
         when(this) {
             {%- for variant in e.variants() %}
             is {{ e.name()|class_name_kt }}.{{ variant.name()|class_name_kt }} -> {
-                {% for field in variant.fields() -%}
-                    {%- if ci.item_contains_object_references(field) -%}
-                    this.{{ field.name() }}?.destroy()
-                    {% endif -%}
-                {%- endfor %}
+                {%- if variant.has_fields() %}
+                {% call kt::destroy_fields(variant) %}
+                {% else -%}
+                // Nothing to destroy
+                {%- endif %}
             }
             {%- endfor %}
         }.let { /* this makes the `when` an expression, which ensures it is exhaustive */ }
@@ -103,4 +103,4 @@ sealed class {{ e.name()|class_name_kt }}{% if ci.item_contains_object_reference
     {% endif %}
 }
 
-{% endif %}
+{% endif %}
\ No newline at end of file
