@@ -1,13 +1,13 @@
 @Synchronized
-fun findLibraryName(componentName: String): String {
-    val libOverride = System.getProperty("uniffi.component.${componentName}.libraryOverride")
+private fun findLibraryName(componentName: String): String {
+    val libOverride = System.getProperty("uniffi.component.$componentName.libraryOverride")
     if (libOverride != null) {
         return libOverride
     }
     return "{{ config.cdylib_name() }}"
 }
 
-inline fun <reified Lib : Library> loadIndirect(
+private inline fun <reified Lib : Library> loadIndirect(
     componentName: String
 ): Lib {
     return Native.load<Lib>(findLibraryName(componentName), Lib::class.java)
@@ -18,13 +18,13 @@ inline fun <reified Lib : Library> loadIndirect(
 
 internal interface _UniFFILib : Library {
     companion object {
-        internal val INSTANCE: _UniFFILib by lazy { 
+        internal val INSTANCE: _UniFFILib by lazy {
             loadIndirect<_UniFFILib>(componentName = "{{ ci.namespace() }}")
-            {% let callback_interfaces = ci.iter_callback_interface_definitions() %}
-            {%- if !callback_interfaces.is_empty() -%}
+            {% let initialization_code = self.initialization_code() %}
+            {%- if !initialization_code.is_empty() -%}
             .also { lib: _UniFFILib ->
-                {% for cb in callback_interfaces -%}
-                CallbackInterface{{ cb.name()|class_name_kt }}Internals.register(lib)
+                {% for code in initialization_code -%}
+                {{ code }}
                 {% endfor -%}
             }
             {% endif %}
