@@ -15,12 +15,13 @@ use std::path::Path;
 use crate::interface::ComponentInterface;
 use crate::MergeWith;
 
-pub mod gecko_js;
 pub mod kotlin;
 pub mod python;
 pub mod ruby;
 pub mod swift;
 
+pub mod backend;
+
 /// Enumeration of all foreign language targets currently supported by this crate.
 ///
 /// The functions in this module will delegate to a language-specific backend based
@@ -33,7 +34,6 @@ pub enum TargetLanguage {
     Swift,
     Python,
     Ruby,
-    GeckoJs,
 }
 
 impl TryFrom<&str> for TargetLanguage {
@@ -44,7 +44,6 @@ impl TryFrom<&str> for TargetLanguage {
             "swift" => TargetLanguage::Swift,
             "python" | "py" => TargetLanguage::Python,
             "ruby" | "rb" => TargetLanguage::Ruby,
-            "gecko_js" => TargetLanguage::GeckoJs,
             _ => bail!("Unknown or unsupported target language: \"{}\"", value),
         })
     }
@@ -77,8 +76,6 @@ pub struct Config {
     python: python::Config,
     #[serde(default)]
     ruby: ruby::Config,
-    #[serde(default)]
-    gecko_js: gecko_js::Config,
 }
 
 impl From<&ComponentInterface> for Config {
@@ -88,7 +85,6 @@ impl From<&ComponentInterface> for Config {
             swift: ci.into(),
             python: ci.into(),
             ruby: ci.into(),
-            gecko_js: ci.into(),
         }
     }
 }
@@ -100,7 +96,6 @@ impl MergeWith for Config {
             swift: self.swift.merge_with(&other.swift),
             python: self.python.merge_with(&other.python),
             ruby: self.ruby.merge_with(&other.ruby),
-            gecko_js: self.gecko_js.merge_with(&other.gecko_js),
         }
     }
 }
@@ -112,7 +107,6 @@ pub fn write_bindings<P>(
     out_dir: P,
     language: TargetLanguage,
     try_format_code: bool,
-    is_testing: bool,
 ) -> Result<()>
 where
     P: AsRef<Path>,
@@ -120,20 +114,15 @@ where
     let out_dir = out_dir.as_ref();
     match language {
         TargetLanguage::Kotlin => {
-            kotlin::write_bindings(&config.kotlin, &ci, out_dir, try_format_code, is_testing)?
+            kotlin::write_bindings(&config.kotlin, ci, out_dir, try_format_code)?
         }
         TargetLanguage::Swift => {
-            swift::write_bindings(&config.swift, &ci, out_dir, try_format_code, is_testing)?
+            swift::write_bindings(&config.swift, ci, out_dir, try_format_code)?
         }
         TargetLanguage::Python => {
-            python::write_bindings(&config.python, &ci, out_dir, try_format_code, is_testing)?
-        }
-        TargetLanguage::Ruby => {
-            ruby::write_bindings(&config.ruby, &ci, out_dir, try_format_code, is_testing)?
-        }
-        TargetLanguage::GeckoJs => {
-            gecko_js::write_bindings(&config.gecko_js, &ci, out_dir, try_format_code, is_testing)?
+            python::write_bindings(&config.python, ci, out_dir, try_format_code)?
         }
+        TargetLanguage::Ruby => ruby::write_bindings(&config.ruby, ci, out_dir, try_format_code)?,
     }
     Ok(())
 }
@@ -150,11 +139,10 @@ where
 {
     let out_dir = out_dir.as_ref();
     match language {
-        TargetLanguage::Kotlin => kotlin::compile_bindings(&config.kotlin, &ci, out_dir)?,
-        TargetLanguage::Swift => swift::compile_bindings(&config.swift, &ci, out_dir)?,
+        TargetLanguage::Kotlin => kotlin::compile_bindings(&config.kotlin, ci, out_dir)?,
+        TargetLanguage::Swift => swift::compile_bindings(&config.swift, ci, out_dir)?,
         TargetLanguage::Python => (),
         TargetLanguage::Ruby => (),
-        TargetLanguage::GeckoJs => (),
     }
     Ok(())
 }
@@ -172,7 +160,6 @@ where
         TargetLanguage::Swift => swift::run_script(out_dir, script_file)?,
         TargetLanguage::Python => python::run_script(out_dir, script_file)?,
         TargetLanguage::Ruby => ruby::run_script(out_dir, script_file)?,
-        TargetLanguage::GeckoJs => bail!("Can't run Gecko code standalone"),
     }
     Ok(())
 }
