@@ -62,6 +62,10 @@ pub enum Type {
     Optional(Box<Type>),
     Sequence(Box<Type>),
     Map(/* String, */ Box<Type>),
+    // An FfiConverter we `use` from an external crate
+    External { name: String, crate_name: String },
+    // A local type we will generate an FfiConverter via wrapping a primitive.
+    Wrapped { name: String, prim: Box<Type> },
 }
 
 impl Type {
@@ -89,11 +93,13 @@ impl Type {
             // API defined types.
             // Note that these all get unique names, and the parser ensures that the names do not
             // conflict with a builtin type. We add a prefix to the name to guard against pathological
-            // cases like a record named `SequenceRecord` interfering with `sequence<Record>`
-            Type::Object(nm) => format!("Object{}", nm),
-            Type::Error(nm) => format!("Error{}", nm),
-            Type::Enum(nm) => format!("Enum{}", nm),
-            Type::Record(nm) => format!("Record{}", nm),
+            // cases like a record named `SequenceRecord` interfering with `sequence<Record>`.
+            // However, types that support importing all end up with the same prefix of "Type", so
+            // that the import handling code knows how to find the remote reference.
+            Type::Object(nm) => format!("Type{}", nm),
+            Type::Error(nm) => format!("Type{}", nm),
+            Type::Enum(nm) => format!("Type{}", nm),
+            Type::Record(nm) => format!("Type{}", nm),
             Type::CallbackInterface(nm) => format!("CallbackInterface{}", nm),
             Type::Timestamp => "Timestamp".into(),
             Type::Duration => "Duration".into(),
@@ -105,6 +111,8 @@ impl Type {
             Type::Optional(t) => format!("Optional{}", t.canonical_name()),
             Type::Sequence(t) => format!("Sequence{}", t.canonical_name()),
             Type::Map(t) => format!("Map{}", t.canonical_name()),
+            // A type that exists externally.
+            Type::External { name, .. } | Type::Wrapped { name, .. } => format!("Type{}", name),
         }
     }
 }
@@ -145,7 +153,9 @@ impl From<&Type> for FFIType {
             | Type::Sequence(_)
             | Type::Map(_)
             | Type::Timestamp
-            | Type::Duration => FFIType::RustBuffer,
+            | Type::Duration
+            | Type::External { .. } => FFIType::RustBuffer,
+            Type::Wrapped { prim, .. } => FFIType::from(prim.as_ref()),
         }
     }
 }
@@ -303,7 +313,7 @@ mod test_type {
                 "Example".into()
             )))))
             .canonical_name(),
-            "OptionalSequenceObjectExample"
+            "OptionalSequenceTypeExample"
         );
     }
 }
